@@ -114,9 +114,14 @@ class FeeDunningLevel(ModelSQL, ModelView):
 
     @classmethod
     def search_rec_name(cls, name, clause):
-        return ['OR',
-            ('dunning.rec_name',) + tuple(clause[1:]),
-            ('level.rec_name',) + tuple(clause[1:]),
+        _, operator, value = clause
+        if operator.startswith('!') or operator.startswith('not '):
+            bool_op = 'AND'
+        else:
+            bool_op = 'OR'
+        return [bool_op,
+            ('dunning.rec_name', *clause[1:]),
+            ('level.rec_name', *clause[1:]),
             ]
 
     @classmethod
